General MX-Bluesky Developer Guide
==================================

Documentation is split into four categories, and each is also accessible from links in the side-bar.

.. grid:: 2
    :gutter: 2

    .. grid-item-card:: :material-regular:`directions_run;3em`

        .. toctree::
            :caption: Tutorials
            :maxdepth: 1

            tutorials/profile-tests

        +++

        Tutorials for getting up and running as a developer.

    .. grid-item-card:: :material-regular:`task;3em`

        .. toctree::
            :caption: How-to Guides
            :maxdepth: 1

            how-to/get-started
            how-to/contribute
            how-to/create-a-release
            how-to/deploy-a-release
            how-to/dev-ops/dev-ops

        +++

        Practical step-by-step guides for day-to-day dev tasks.

    .. grid-item-card:: :material-regular:`apartment;3em`

        .. toctree::
            :caption: Explanations
            :maxdepth: 1

            explanations/decisions
            explanations/callback_and_run_logic

        +++

        Explanations of how and why the architecture is why it is.

    .. grid-item-card:: :material-regular:`description;3em`

        .. toctree::
            :caption: Reference
            :maxdepth: 1

            reference/standards

        +++

        Technical reference material on standards in use.
